@@ -5,7 +5,7 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.latest.meta_v1 import DeleteOptions  # noqa: F401
+from kuber.latest.meta_v1 import Condition  # noqa: F401
 from kuber.latest.meta_v1 import LabelSelector  # noqa: F401
 from kuber.latest.meta_v1 import ListMeta  # noqa: F401
 from kuber.latest.meta_v1 import ObjectMeta  # noqa: F401
@@ -182,196 +182,6 @@ class AllowedHostPath(_kuber_definitions.Definition):
         return False
 
 
-class Eviction(_kuber_definitions.Resource):
-    """
-    Eviction evicts a pod from its node subject to certain
-    policies and safety constraints. This is a subresource of
-    Pod.  A request to cause such an eviction is created by
-    POSTing to .../pods/<pod name>/evictions.
-    """
-
-    def __init__(
-        self,
-        delete_options: "DeleteOptions" = None,
-        metadata: "ObjectMeta" = None,
-    ):
-        """Create Eviction instance."""
-        super(Eviction, self).__init__(api_version="policy/v1beta1", kind="Eviction")
-        self._properties = {
-            "deleteOptions": delete_options
-            if delete_options is not None
-            else DeleteOptions(),
-            "metadata": metadata if metadata is not None else ObjectMeta(),
-        }
-        self._types = {
-            "apiVersion": (str, None),
-            "deleteOptions": (DeleteOptions, None),
-            "kind": (str, None),
-            "metadata": (ObjectMeta, None),
-        }
-
-    @property
-    def delete_options(self) -> "DeleteOptions":
-        """
-        DeleteOptions may be provided
-        """
-        return typing.cast(
-            "DeleteOptions",
-            self._properties.get("deleteOptions"),
-        )
-
-    @delete_options.setter
-    def delete_options(self, value: typing.Union["DeleteOptions", dict]):
-        """
-        DeleteOptions may be provided
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                DeleteOptions,
-                DeleteOptions().from_dict(value),
-            )
-        self._properties["deleteOptions"] = value
-
-    @property
-    def metadata(self) -> "ObjectMeta":
-        """
-        ObjectMeta describes the pod that is being evicted.
-        """
-        return typing.cast(
-            "ObjectMeta",
-            self._properties.get("metadata"),
-        )
-
-    @metadata.setter
-    def metadata(self, value: typing.Union["ObjectMeta", dict]):
-        """
-        ObjectMeta describes the pod that is being evicted.
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                ObjectMeta,
-                ObjectMeta().from_dict(value),
-            )
-        self._properties["metadata"] = value
-
-    def create_resource(self, namespace: "str" = None):
-        """
-        Creates the Eviction in the currently
-        configured Kubernetes cluster.
-        """
-        names = ["create_namespaced_eviction", "create_eviction"]
-
-        _kube_api.execute(
-            action="create",
-            resource=self,
-            names=names,
-            namespace=namespace,
-            api_client=None,
-            api_args={"body": self.to_dict()},
-        )
-
-    def replace_resource(self, namespace: "str" = None):
-        """
-        Replaces the Eviction in the currently
-        configured Kubernetes cluster.
-        """
-        names = ["replace_namespaced_eviction", "replace_eviction"]
-
-        _kube_api.execute(
-            action="replace",
-            resource=self,
-            names=names,
-            namespace=namespace,
-            api_client=None,
-            api_args={"body": self.to_dict(), "name": self.metadata.name},
-        )
-
-    def patch_resource(self, namespace: "str" = None):
-        """
-        Patches the Eviction in the currently
-        configured Kubernetes cluster.
-        """
-        names = ["patch_namespaced_eviction", "patch_eviction"]
-
-        _kube_api.execute(
-            action="patch",
-            resource=self,
-            names=names,
-            namespace=namespace,
-            api_client=None,
-            api_args={"body": self.to_dict(), "name": self.metadata.name},
-        )
-
-    def get_resource_status(self, namespace: "str" = None):
-        """This resource does not have a status."""
-        pass
-
-    def read_resource(self, namespace: str = None):
-        """
-        Reads the Eviction from the currently configured
-        Kubernetes cluster and returns the low-level definition object.
-        """
-        names = [
-            "read_namespaced_eviction",
-            "read_eviction",
-        ]
-        return _kube_api.execute(
-            action="read",
-            resource=self,
-            names=names,
-            namespace=namespace,
-            api_client=None,
-            api_args={"name": self.metadata.name},
-        )
-
-    def delete_resource(
-        self,
-        namespace: str = None,
-        propagation_policy: str = "Foreground",
-        grace_period_seconds: int = 10,
-    ):
-        """
-        Deletes the Eviction from the currently configured
-        Kubernetes cluster.
-        """
-        names = [
-            "delete_namespaced_eviction",
-            "delete_eviction",
-        ]
-
-        body = client.V1DeleteOptions(
-            propagation_policy=propagation_policy,
-            grace_period_seconds=grace_period_seconds,
-        )
-
-        _kube_api.execute(
-            action="delete",
-            resource=self,
-            names=names,
-            namespace=namespace,
-            api_client=None,
-            api_args={"name": self.metadata.name, "body": body},
-        )
-
-    @staticmethod
-    def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
-    ) -> "client.PolicyV1beta1Api":
-        """
-        Returns an instance of the kubernetes API client associated with
-        this object.
-        """
-        if api_client:
-            kwargs["apl_client"] = api_client
-        return client.PolicyV1beta1Api(**kwargs)
-
-    def __enter__(self) -> "Eviction":
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        return False
-
-
 class FSGroupStrategyOptions(_kuber_definitions.Definition):
     """
     FSGroupStrategyOptions defines the strategy type and options
@@ -610,7 +420,11 @@ class PodDisruptionBudget(_kuber_definitions.Resource):
 
     @property
     def metadata(self) -> "ObjectMeta":
-        """"""
+        """
+        Standard object's metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         return typing.cast(
             "ObjectMeta",
             self._properties.get("metadata"),
@@ -618,7 +432,11 @@ class PodDisruptionBudget(_kuber_definitions.Resource):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
-        """"""
+        """
+        Standard object's metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         if isinstance(value, dict):
             value = typing.cast(
                 ObjectMeta,
@@ -866,7 +684,9 @@ class PodDisruptionBudgetList(_kuber_definitions.Collection):
 
     @property
     def items(self) -> typing.List["PodDisruptionBudget"]:
-        """"""
+        """
+        items list individual PodDisruptionBudget objects
+        """
         return typing.cast(
             typing.List["PodDisruptionBudget"],
             self._properties.get("items"),
@@ -876,7 +696,9 @@ class PodDisruptionBudgetList(_kuber_definitions.Collection):
     def items(
         self, value: typing.Union[typing.List["PodDisruptionBudget"], typing.List[dict]]
     ):
-        """"""
+        """
+        items list individual PodDisruptionBudget objects
+        """
         cleaned: typing.List[PodDisruptionBudget] = []
         for item in value:
             if isinstance(item, dict):
@@ -889,7 +711,11 @@ class PodDisruptionBudgetList(_kuber_definitions.Collection):
 
     @property
     def metadata(self) -> "ListMeta":
-        """"""
+        """
+        Standard object's metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         return typing.cast(
             "ListMeta",
             self._properties.get("metadata"),
@@ -897,7 +723,11 @@ class PodDisruptionBudgetList(_kuber_definitions.Collection):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ListMeta", dict]):
-        """"""
+        """
+        Standard object's metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         if isinstance(value, dict):
             value = typing.cast(
                 ListMeta,
@@ -1005,7 +835,10 @@ class PodDisruptionBudgetSpec(_kuber_definitions.Definition):
     def selector(self) -> "LabelSelector":
         """
         Label query over pods whose evictions are managed by the
-        disruption budget.
+        disruption budget. A null selector selects no pods. An empty
+        selector ({}) also selects no pods, which differs from
+        standard behavior of selecting all pods. In policy/v1, an
+        empty selector will select all pods in the namespace.
         """
         return typing.cast(
             "LabelSelector",
@@ -1016,7 +849,10 @@ class PodDisruptionBudgetSpec(_kuber_definitions.Definition):
     def selector(self, value: typing.Union["LabelSelector", dict]):
         """
         Label query over pods whose evictions are managed by the
-        disruption budget.
+        disruption budget. A null selector selects no pods. An empty
+        selector ({}) also selects no pods, which differs from
+        standard behavior of selecting all pods. In policy/v1, an
+        empty selector will select all pods in the namespace.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1041,6 +877,7 @@ class PodDisruptionBudgetStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
+        conditions: typing.List["Condition"] = None,
         current_healthy: int = None,
         desired_healthy: int = None,
         disrupted_pods: dict = None,
@@ -1053,6 +890,7 @@ class PodDisruptionBudgetStatus(_kuber_definitions.Definition):
             api_version="policy/v1beta1", kind="PodDisruptionBudgetStatus"
         )
         self._properties = {
+            "conditions": conditions if conditions is not None else [],
             "currentHealthy": current_healthy if current_healthy is not None else None,
             "desiredHealthy": desired_healthy if desired_healthy is not None else None,
             "disruptedPods": disrupted_pods if disrupted_pods is not None else {},
@@ -1065,6 +903,7 @@ class PodDisruptionBudgetStatus(_kuber_definitions.Definition):
             else None,
         }
         self._types = {
+            "conditions": (list, Condition),
             "currentHealthy": (int, None),
             "desiredHealthy": (int, None),
             "disruptedPods": (dict, None),
@@ -1073,6 +912,73 @@ class PodDisruptionBudgetStatus(_kuber_definitions.Definition):
             "observedGeneration": (int, None),
         }
 
+    @property
+    def conditions(self) -> typing.List["Condition"]:
+        """
+        Conditions contain conditions for PDB. The disruption
+        controller sets the DisruptionAllowed condition. The
+        following are known values for the reason field (additional
+        reasons could be added in the future): - SyncFailed: The
+        controller encountered an error and wasn't able to compute
+                      the number of allowed disruptions. Therefore
+        no disruptions are
+                      allowed and the status of the condition will
+        be False.
+        - InsufficientPods: The number of pods are either at or
+        below the number
+                            required by the PodDisruptionBudget. No
+        disruptions are
+                            allowed and the status of the condition
+        will be False.
+        - SufficientPods: There are more pods than required by the
+        PodDisruptionBudget.
+                          The condition will be True, and the number
+        of allowed
+                          disruptions are provided by the
+        disruptionsAllowed property.
+        """
+        return typing.cast(
+            typing.List["Condition"],
+            self._properties.get("conditions"),
+        )
+
+    @conditions.setter
+    def conditions(
+        self, value: typing.Union[typing.List["Condition"], typing.List[dict]]
+    ):
+        """
+        Conditions contain conditions for PDB. The disruption
+        controller sets the DisruptionAllowed condition. The
+        following are known values for the reason field (additional
+        reasons could be added in the future): - SyncFailed: The
+        controller encountered an error and wasn't able to compute
+                      the number of allowed disruptions. Therefore
+        no disruptions are
+                      allowed and the status of the condition will
+        be False.
+        - InsufficientPods: The number of pods are either at or
+        below the number
+                            required by the PodDisruptionBudget. No
+        disruptions are
+                            allowed and the status of the condition
+        will be False.
+        - SufficientPods: There are more pods than required by the
+        PodDisruptionBudget.
+                          The condition will be True, and the number
+        of allowed
+                          disruptions are provided by the
+        disruptionsAllowed property.
+        """
+        cleaned: typing.List[Condition] = []
+        for item in value:
+            if isinstance(item, dict):
+                item = typing.cast(
+                    Condition,
+                    Condition().from_dict(item),
+                )
+            cleaned.append(typing.cast(Condition, item))
+        self._properties["conditions"] = cleaned
+
     @property
     def current_healthy(self) -> int:
         """
@@ -1220,7 +1126,7 @@ class PodSecurityPolicy(_kuber_definitions.Resource):
     """
     PodSecurityPolicy governs the ability to make requests that
     affect the Security Context that will be applied to a pod
-    and container.
+    and container. Deprecated in 1.21.
     """
 
     def __init__(
