@@ -43,7 +43,11 @@ class APIService(_kuber_definitions.Resource):
 
     @property
     def metadata(self) -> "ObjectMeta":
-        """"""
+        """
+        Standard object's metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         return typing.cast(
             "ObjectMeta",
             self._properties.get("metadata"),
@@ -51,7 +55,11 @@ class APIService(_kuber_definitions.Resource):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
-        """"""
+        """
+        Standard object's metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         if isinstance(value, dict):
             value = typing.cast(
                 ObjectMeta,
@@ -428,7 +436,9 @@ class APIServiceList(_kuber_definitions.Collection):
 
     @property
     def items(self) -> typing.List["APIService"]:
-        """"""
+        """
+        Items is the list of APIService
+        """
         return typing.cast(
             typing.List["APIService"],
             self._properties.get("items"),
@@ -436,7 +446,9 @@ class APIServiceList(_kuber_definitions.Collection):
 
     @items.setter
     def items(self, value: typing.Union[typing.List["APIService"], typing.List[dict]]):
-        """"""
+        """
+        Items is the list of APIService
+        """
         cleaned: typing.List[APIService] = []
         for item in value:
             if isinstance(item, dict):
@@ -449,7 +461,11 @@ class APIServiceList(_kuber_definitions.Collection):
 
     @property
     def metadata(self) -> "ListMeta":
-        """"""
+        """
+        Standard list metadata More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         return typing.cast(
             "ListMeta",
             self._properties.get("metadata"),
@@ -457,7 +473,11 @@ class APIServiceList(_kuber_definitions.Collection):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ListMeta", dict]):
-        """"""
+        """
+        Standard list metadata More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         if isinstance(value, dict):
             value = typing.cast(
                 ListMeta,
