@@ -64,8 +64,8 @@ class RuntimeClass(_kuber_definitions.Resource):
     cluster provisioner, and referenced in the PodSpec. The
     Kubelet is responsible for resolving the RuntimeClassName
     reference before running the pod.  For more details, see
-    https://git.k8s.io/enhancements/keps/sig-node/runtime-
-    class.md
+    https://git.k8s.io/enhancements/keps/sig-node/585-runtime-
+    class
     """
 
     def __init__(
@@ -391,10 +391,10 @@ class RuntimeClassSpec(_kuber_definitions.Definition):
         """
         Overhead represents the resource overhead associated with
         running a pod for a given RuntimeClass. For more details,
-        see https://git.k8s.io/enhancements/keps/sig-
-        node/20190226-pod-overhead.md This field is alpha-level as
-        of Kubernetes v1.15, and is only honored by servers that
-        enable the PodOverhead feature.
+        see https://git.k8s.io/enhancements/keps/sig-node/688-pod-
+        overhead/README.md This field is beta-level as of Kubernetes
+        v1.18, and is only honored by servers that enable the
+        PodOverhead feature.
         """
         return typing.cast(
             "Overhead",
@@ -406,10 +406,10 @@ class RuntimeClassSpec(_kuber_definitions.Definition):
         """
         Overhead represents the resource overhead associated with
         running a pod for a given RuntimeClass. For more details,
-        see https://git.k8s.io/enhancements/keps/sig-
-        node/20190226-pod-overhead.md This field is alpha-level as
-        of Kubernetes v1.15, and is only honored by servers that
-        enable the PodOverhead feature.
+        see https://git.k8s.io/enhancements/keps/sig-node/688-pod-
+        overhead/README.md This field is beta-level as of Kubernetes
+        v1.18, and is only honored by servers that enable the
+        PodOverhead feature.
         """
         if isinstance(value, dict):
             value = typing.cast(
