@@ -6,10 +6,10 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_16.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_16.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_16.meta_v1 import Status  # noqa: F401
-from kuber.v1_16.meta_v1 import StatusDetails  # noqa: F401
+from kuber.v1_18.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_18.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_18.meta_v1 import Status  # noqa: F401
+from kuber.v1_18.meta_v1 import StatusDetails  # noqa: F401
 
 
 class CertificateSigningRequest(_kuber_definitions.Resource):
@@ -44,7 +44,7 @@ class CertificateSigningRequest(_kuber_definitions.Resource):
 
     @property
     def metadata(self) -> "ObjectMeta":
-        """"""
+        """ """
         return typing.cast(
             "ObjectMeta",
             self._properties.get("metadata"),
@@ -52,7 +52,7 @@ class CertificateSigningRequest(_kuber_definitions.Resource):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
-        """"""
+        """ """
         if isinstance(value, dict):
             value = typing.cast(
                 ObjectMeta,
@@ -279,7 +279,7 @@ class CertificateSigningRequest(_kuber_definitions.Resource):
 
 
 class CertificateSigningRequestCondition(_kuber_definitions.Definition):
-    """"""
+    """ """
 
     def __init__(
         self,
@@ -390,7 +390,7 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
 
 
 class CertificateSigningRequestList(_kuber_definitions.Collection):
-    """"""
+    """ """
 
     def __init__(
         self,
@@ -414,7 +414,7 @@ class CertificateSigningRequestList(_kuber_definitions.Collection):
 
     @property
     def items(self) -> typing.List["CertificateSigningRequest"]:
-        """"""
+        """ """
         return typing.cast(
             typing.List["CertificateSigningRequest"],
             self._properties.get("items"),
@@ -427,7 +427,7 @@ class CertificateSigningRequestList(_kuber_definitions.Collection):
             typing.List["CertificateSigningRequest"], typing.List[dict]
         ],
     ):
-        """"""
+        """ """
         cleaned: typing.List[CertificateSigningRequest] = []
         for item in value:
             if isinstance(item, dict):
@@ -440,7 +440,7 @@ class CertificateSigningRequestList(_kuber_definitions.Collection):
 
     @property
     def metadata(self) -> "ListMeta":
-        """"""
+        """ """
         return typing.cast(
             "ListMeta",
             self._properties.get("metadata"),
@@ -448,7 +448,7 @@ class CertificateSigningRequestList(_kuber_definitions.Collection):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ListMeta", dict]):
-        """"""
+        """ """
         if isinstance(value, dict):
             value = typing.cast(
                 ListMeta,
@@ -488,6 +488,7 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         extra: dict = None,
         groups: typing.List[str] = None,
         request: str = None,
+        signer_name: str = None,
         uid: str = None,
         usages: typing.List[str] = None,
         username: str = None,
@@ -500,6 +501,7 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
             "extra": extra if extra is not None else {},
             "groups": groups if groups is not None else [],
             "request": request if request is not None else "",
+            "signerName": signer_name if signer_name is not None else "",
             "uid": uid if uid is not None else "",
             "usages": usages if usages is not None else [],
             "username": username if username is not None else "",
@@ -508,6 +510,7 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
             "extra": (dict, None),
             "groups": (list, str),
             "request": (str, None),
+            "signerName": (str, None),
             "uid": (str, None),
             "usages": (list, str),
             "username": (str, None),
@@ -568,6 +571,43 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         """
         self._properties["request"] = value
 
+    @property
+    def signer_name(self) -> str:
+        """
+        Requested signer for the request. It is a qualified name in
+        the form: `scope-hostname.io/name`. If empty, it will be
+        defaulted:
+         1. If it's a kubelet client certificate, it is assigned
+            "kubernetes.io/kube-apiserver-client-kubelet".
+         2. If it's a kubelet serving certificate, it is assigned
+            "kubernetes.io/kubelet-serving".
+         3. Otherwise, it is assigned "kubernetes.io/legacy-
+        unknown".
+        Distribution of trust for signers happens out of band. You
+        can select on this field using `spec.signerName`.
+        """
+        return typing.cast(
+            str,
+            self._properties.get("signerName"),
+        )
+
+    @signer_name.setter
+    def signer_name(self, value: str):
+        """
+        Requested signer for the request. It is a qualified name in
+        the form: `scope-hostname.io/name`. If empty, it will be
+        defaulted:
+         1. If it's a kubelet client certificate, it is assigned
+            "kubernetes.io/kube-apiserver-client-kubelet".
+         2. If it's a kubelet serving certificate, it is assigned
+            "kubernetes.io/kubelet-serving".
+         3. Otherwise, it is assigned "kubernetes.io/legacy-
+        unknown".
+        Distribution of trust for signers happens out of band. You
+        can select on this field using `spec.signerName`.
+        """
+        self._properties["signerName"] = value
+
     @property
     def uid(self) -> str:
         """
@@ -637,7 +677,7 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
 
 
 class CertificateSigningRequestStatus(_kuber_definitions.Definition):
-    """"""
+    """ """
 
     def __init__(
         self,
