@@ -6,11 +6,11 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_15.core_v1 import EventSource  # noqa: F401
-from kuber.v1_15.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_15.meta_v1 import MicroTime  # noqa: F401
-from kuber.v1_15.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_15.core_v1 import ObjectReference  # noqa: F401
+from kuber.v1_19.core_v1 import EventSource  # noqa: F401
+from kuber.v1_19.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_19.meta_v1 import MicroTime  # noqa: F401
+from kuber.v1_19.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_19.core_v1 import ObjectReference  # noqa: F401
 
 
 class Event(_kuber_definitions.Resource):
@@ -91,8 +91,9 @@ class Event(_kuber_definitions.Resource):
     @property
     def action(self) -> str:
         """
-        What action was taken/failed regarding to the regarding
-        object.
+        action is what action was taken/failed regarding to the
+        regarding object. It is machine-readable. This field can
+        have at most 128 characters.
         """
         return typing.cast(
             str,
@@ -102,16 +103,17 @@ class Event(_kuber_definitions.Resource):
     @action.setter
     def action(self, value: str):
         """
-        What action was taken/failed regarding to the regarding
-        object.
+        action is what action was taken/failed regarding to the
+        regarding object. It is machine-readable. This field can
+        have at most 128 characters.
         """
         self._properties["action"] = value
 
     @property
     def deprecated_count(self) -> int:
         """
-        Deprecated field assuring backward compatibility with
-        core.v1 Event type
+        deprecatedCount is the deprecated field assuring backward
+        compatibility with core.v1 Event type.
         """
         return typing.cast(
             int,
@@ -121,16 +123,16 @@ class Event(_kuber_definitions.Resource):
     @deprecated_count.setter
     def deprecated_count(self, value: int):
         """
-        Deprecated field assuring backward compatibility with
-        core.v1 Event type
+        deprecatedCount is the deprecated field assuring backward
+        compatibility with core.v1 Event type.
         """
         self._properties["deprecatedCount"] = value
 
     @property
     def deprecated_first_timestamp(self) -> str:
         """
-        Deprecated field assuring backward compatibility with
-        core.v1 Event type
+        deprecatedFirstTimestamp is the deprecated field assuring
+        backward compatibility with core.v1 Event type.
         """
         return typing.cast(
             str,
@@ -142,8 +144,8 @@ class Event(_kuber_definitions.Resource):
         self, value: typing.Union[str, _datetime.datetime, _datetime.date]
     ):
         """
-        Deprecated field assuring backward compatibility with
-        core.v1 Event type
+        deprecatedFirstTimestamp is the deprecated field assuring
+        backward compatibility with core.v1 Event type.
         """
         if isinstance(value, _datetime.datetime):
             value = value.strftime("%Y-%m-%dT%H:%M:%SZ")
@@ -154,8 +156,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def deprecated_last_timestamp(self) -> str:
         """
-        Deprecated field assuring backward compatibility with
-        core.v1 Event type
+        deprecatedLastTimestamp is the deprecated field assuring
+        backward compatibility with core.v1 Event type.
         """
         return typing.cast(
             str,
@@ -167,8 +169,8 @@ class Event(_kuber_definitions.Resource):
         self, value: typing.Union[str, _datetime.datetime, _datetime.date]
     ):
         """
-        Deprecated field assuring backward compatibility with
-        core.v1 Event type
+        deprecatedLastTimestamp is the deprecated field assuring
+        backward compatibility with core.v1 Event type.
         """
         if isinstance(value, _datetime.datetime):
             value = value.strftime("%Y-%m-%dT%H:%M:%SZ")
@@ -179,8 +181,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def deprecated_source(self) -> "EventSource":
         """
-        Deprecated field assuring backward compatibility with
-        core.v1 Event type
+        deprecatedSource is the deprecated field assuring backward
+        compatibility with core.v1 Event type.
         """
         return typing.cast(
             "EventSource",
@@ -190,8 +192,8 @@ class Event(_kuber_definitions.Resource):
     @deprecated_source.setter
     def deprecated_source(self, value: typing.Union["EventSource", dict]):
         """
-        Deprecated field assuring backward compatibility with
-        core.v1 Event type
+        deprecatedSource is the deprecated field assuring backward
+        compatibility with core.v1 Event type.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -203,7 +205,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def event_time(self) -> "MicroTime":
         """
-        Required. Time when this Event was first observed.
+        eventTime is the time when this Event was first observed. It
+        is required.
         """
         return typing.cast(
             "MicroTime",
@@ -213,7 +216,8 @@ class Event(_kuber_definitions.Resource):
     @event_time.setter
     def event_time(self, value: typing.Union["MicroTime", dict]):
         """
-        Required. Time when this Event was first observed.
+        eventTime is the time when this Event was first observed. It
+        is required.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -224,7 +228,7 @@ class Event(_kuber_definitions.Resource):
 
     @property
     def metadata(self) -> "ObjectMeta":
-        """"""
+        """ """
         return typing.cast(
             "ObjectMeta",
             self._properties.get("metadata"),
@@ -232,7 +236,7 @@ class Event(_kuber_definitions.Resource):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
-        """"""
+        """ """
         if isinstance(value, dict):
             value = typing.cast(
                 ObjectMeta,
@@ -243,7 +247,7 @@ class Event(_kuber_definitions.Resource):
     @property
     def note(self) -> str:
         """
-        Optional. A human-readable description of the status of this
+        note is a human-readable description of the status of this
         operation. Maximal length of the note is 1kB, but libraries
         should be prepared to handle values up to 64kB.
         """
@@ -255,7 +259,7 @@ class Event(_kuber_definitions.Resource):
     @note.setter
     def note(self, value: str):
         """
-        Optional. A human-readable description of the status of this
+        note is a human-readable description of the status of this
         operation. Maximal length of the note is 1kB, but libraries
         should be prepared to handle values up to 64kB.
         """
@@ -264,7 +268,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def reason(self) -> str:
         """
-        Why the action was taken.
+        reason is why the action was taken. It is human-readable.
+        This field can have at most 128 characters.
         """
         return typing.cast(
             str,
@@ -274,17 +279,19 @@ class Event(_kuber_definitions.Resource):
     @reason.setter
     def reason(self, value: str):
         """
-        Why the action was taken.
+        reason is why the action was taken. It is human-readable.
+        This field can have at most 128 characters.
         """
         self._properties["reason"] = value
 
     @property
     def regarding(self) -> "ObjectReference":
         """
-        The object this Event is about. In most cases it's an Object
-        reporting controller implements. E.g. ReplicaSetController
-        implements ReplicaSets and this event is emitted because it
-        acts on some changes in a ReplicaSet object.
+        regarding contains the object this Event is about. In most
+        cases it's an Object reporting controller implements, e.g.
+        ReplicaSetController implements ReplicaSets and this event
+        is emitted because it acts on some changes in a ReplicaSet
+        object.
         """
         return typing.cast(
             "ObjectReference",
@@ -294,10 +301,11 @@ class Event(_kuber_definitions.Resource):
     @regarding.setter
     def regarding(self, value: typing.Union["ObjectReference", dict]):
         """
-        The object this Event is about. In most cases it's an Object
-        reporting controller implements. E.g. ReplicaSetController
-        implements ReplicaSets and this event is emitted because it
-        acts on some changes in a ReplicaSet object.
+        regarding contains the object this Event is about. In most
+        cases it's an Object reporting controller implements, e.g.
+        ReplicaSetController implements ReplicaSets and this event
+        is emitted because it acts on some changes in a ReplicaSet
+        object.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -309,9 +317,9 @@ class Event(_kuber_definitions.Resource):
     @property
     def related(self) -> "ObjectReference":
         """
-        Optional secondary object for more complex actions. E.g.
-        when regarding object triggers a creation or deletion of
-        related object.
+        related is the optional secondary object for more complex
+        actions. E.g. when regarding object triggers a creation or
+        deletion of related object.
         """
         return typing.cast(
             "ObjectReference",
@@ -321,9 +329,9 @@ class Event(_kuber_definitions.Resource):
     @related.setter
     def related(self, value: typing.Union["ObjectReference", dict]):
         """
-        Optional secondary object for more complex actions. E.g.
-        when regarding object triggers a creation or deletion of
-        related object.
+        related is the optional secondary object for more complex
+        actions. E.g. when regarding object triggers a creation or
+        deletion of related object.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -335,8 +343,9 @@ class Event(_kuber_definitions.Resource):
     @property
     def reporting_controller(self) -> str:
         """
-        Name of the controller that emitted this Event, e.g.
-        `kubernetes.io/kubelet`.
+        reportingController is the name of the controller that
+        emitted this Event, e.g. `kubernetes.io/kubelet`. This field
+        cannot be empty for new Events.
         """
         return typing.cast(
             str,
@@ -346,15 +355,18 @@ class Event(_kuber_definitions.Resource):
     @reporting_controller.setter
     def reporting_controller(self, value: str):
         """
-        Name of the controller that emitted this Event, e.g.
-        `kubernetes.io/kubelet`.
+        reportingController is the name of the controller that
+        emitted this Event, e.g. `kubernetes.io/kubelet`. This field
+        cannot be empty for new Events.
         """
         self._properties["reportingController"] = value
 
     @property
     def reporting_instance(self) -> str:
         """
-        ID of the controller instance, e.g. `kubelet-xyzf`.
+        reportingInstance is the ID of the controller instance, e.g.
+        `kubelet-xyzf`. This field cannot be empty for new Events
+        and it can have at most 128 characters.
         """
         return typing.cast(
             str,
@@ -364,15 +376,17 @@ class Event(_kuber_definitions.Resource):
     @reporting_instance.setter
     def reporting_instance(self, value: str):
         """
-        ID of the controller instance, e.g. `kubelet-xyzf`.
+        reportingInstance is the ID of the controller instance, e.g.
+        `kubelet-xyzf`. This field cannot be empty for new Events
+        and it can have at most 128 characters.
         """
         self._properties["reportingInstance"] = value
 
     @property
     def series(self) -> "EventSeries":
         """
-        Data about the Event series this event represents or nil if
-        it's a singleton Event.
+        series is data about the Event series this event represents
+        or nil if it's a singleton Event.
         """
         return typing.cast(
             "EventSeries",
@@ -382,8 +396,8 @@ class Event(_kuber_definitions.Resource):
     @series.setter
     def series(self, value: typing.Union["EventSeries", dict]):
         """
-        Data about the Event series this event represents or nil if
-        it's a singleton Event.
+        series is data about the Event series this event represents
+        or nil if it's a singleton Event.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -395,8 +409,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def type_(self) -> str:
         """
-        Type of this event (Normal, Warning), new types could be
-        added in the future.
+        type is the type of this event (Normal, Warning), new types
+        could be added in the future. It is machine-readable.
         """
         return typing.cast(
             str,
@@ -406,8 +420,8 @@ class Event(_kuber_definitions.Resource):
     @type_.setter
     def type_(self, value: str):
         """
-        Type of this event (Normal, Warning), new types could be
-        added in the future.
+        type is the type of this event (Normal, Warning), new types
+        could be added in the future. It is machine-readable.
         """
         self._properties["type"] = value
 
@@ -555,7 +569,7 @@ class EventList(_kuber_definitions.Collection):
     @property
     def items(self) -> typing.List["Event"]:
         """
-        Items is a list of schema objects.
+        items is a list of schema objects.
         """
         return typing.cast(
             typing.List["Event"],
@@ -565,7 +579,7 @@ class EventList(_kuber_definitions.Collection):
     @items.setter
     def items(self, value: typing.Union[typing.List["Event"], typing.List[dict]]):
         """
-        Items is a list of schema objects.
+        items is a list of schema objects.
         """
         cleaned: typing.List[Event] = []
         for item in value:
@@ -581,8 +595,8 @@ class EventList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -593,8 +607,8 @@ class EventList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -632,7 +646,6 @@ class EventSeries(_kuber_definitions.Definition):
         self,
         count: int = None,
         last_observed_time: "MicroTime" = None,
-        state: str = None,
     ):
         """Create EventSeries instance."""
         super(EventSeries, self).__init__(
@@ -643,19 +656,17 @@ class EventSeries(_kuber_definitions.Definition):
             "lastObservedTime": last_observed_time
             if last_observed_time is not None
             else MicroTime(),
-            "state": state if state is not None else "",
         }
         self._types = {
             "count": (int, None),
             "lastObservedTime": (MicroTime, None),
-            "state": (str, None),
         }
 
     @property
     def count(self) -> int:
         """
-        Number of occurrences in this series up to the last
-        heartbeat time
+        count is the number of occurrences in this series up to the
+        last heartbeat time.
         """
         return typing.cast(
             int,
@@ -665,16 +676,16 @@ class EventSeries(_kuber_definitions.Definition):
     @count.setter
     def count(self, value: int):
         """
-        Number of occurrences in this series up to the last
-        heartbeat time
+        count is the number of occurrences in this series up to the
+        last heartbeat time.
         """
         self._properties["count"] = value
 
     @property
     def last_observed_time(self) -> "MicroTime":
         """
-        Time when last Event from the series was seen before last
-        heartbeat.
+        lastObservedTime is the time when last Event from the series
+        was seen before last heartbeat.
         """
         return typing.cast(
             "MicroTime",
@@ -684,8 +695,8 @@ class EventSeries(_kuber_definitions.Definition):
     @last_observed_time.setter
     def last_observed_time(self, value: typing.Union["MicroTime", dict]):
         """
-        Time when last Event from the series was seen before last
-        heartbeat.
+        lastObservedTime is the time when last Event from the series
+        was seen before last heartbeat.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -694,25 +705,6 @@ class EventSeries(_kuber_definitions.Definition):
             )
         self._properties["lastObservedTime"] = value
 
-    @property
-    def state(self) -> str:
-        """
-        Information whether this series is ongoing or finished.
-        Deprecated. Planned removal for 1.18
-        """
-        return typing.cast(
-            str,
-            self._properties.get("state"),
-        )
-
-    @state.setter
-    def state(self, value: str):
-        """
-        Information whether this series is ongoing or finished.
-        Deprecated. Planned removal for 1.18
-        """
-        self._properties["state"] = value
-
     def __enter__(self) -> "EventSeries":
         return self
 
