@@ -5,9 +5,9 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_16.meta_v1 import LabelSelector  # noqa: F401
-from kuber.v1_16.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_16.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_19.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_19.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_19.meta_v1 import ObjectMeta  # noqa: F401
 
 
 class AggregationRule(_kuber_definitions.Definition):
@@ -77,7 +77,9 @@ class ClusterRole(_kuber_definitions.Resource):
     """
     ClusterRole is a cluster level, logical grouping of
     PolicyRules that can be referenced as a unit by a
-    RoleBinding or ClusterRoleBinding.
+    RoleBinding or ClusterRoleBinding. Deprecated in v1.17 in
+    favor of rbac.authorization.k8s.io/v1 ClusterRole, and will
+    no longer be served in v1.22.
     """
 
     def __init__(
@@ -302,7 +304,9 @@ class ClusterRoleBinding(_kuber_definitions.Resource):
     """
     ClusterRoleBinding references a ClusterRole, but not contain
     it.  It can reference a ClusterRole in the global namespace,
-    and adds who information via Subject.
+    and adds who information via Subject. Deprecated in v1.17 in
+    favor of rbac.authorization.k8s.io/v1 ClusterRoleBinding,
+    and will no longer be served in v1.22.
     """
 
     def __init__(
@@ -530,7 +534,9 @@ class ClusterRoleBinding(_kuber_definitions.Resource):
 class ClusterRoleBindingList(_kuber_definitions.Collection):
     """
     ClusterRoleBindingList is a collection of
-    ClusterRoleBindings
+    ClusterRoleBindings. Deprecated in v1.17 in favor of
+    rbac.authorization.k8s.io/v1 ClusterRoleBindingList, and
+    will no longer be served in v1.22.
     """
 
     def __init__(
@@ -624,7 +630,9 @@ class ClusterRoleBindingList(_kuber_definitions.Collection):
 
 class ClusterRoleList(_kuber_definitions.Collection):
     """
-    ClusterRoleList is a collection of ClusterRoles
+    ClusterRoleList is a collection of ClusterRoles. Deprecated
+    in v1.17 in favor of rbac.authorization.k8s.io/v1
+    ClusterRoles, and will no longer be served in v1.22.
     """
 
     def __init__(
@@ -876,7 +884,9 @@ class PolicyRule(_kuber_definitions.Definition):
 class Role(_kuber_definitions.Resource):
     """
     Role is a namespaced, logical grouping of PolicyRules that
-    can be referenced as a unit by a RoleBinding.
+    can be referenced as a unit by a RoleBinding. Deprecated in
+    v1.17 in favor of rbac.authorization.k8s.io/v1 Role, and
+    will no longer be served in v1.22.
     """
 
     def __init__(
@@ -1071,7 +1081,9 @@ class RoleBinding(_kuber_definitions.Resource):
     in the global namespace. It adds who information via
     Subjects and namespace information by which namespace it
     exists in.  RoleBindings in a given namespace only have
-    effect in that namespace.
+    effect in that namespace. Deprecated in v1.17 in favor of
+    rbac.authorization.k8s.io/v1 RoleBinding, and will no longer
+    be served in v1.22.
     """
 
     def __init__(
@@ -1292,7 +1304,9 @@ class RoleBinding(_kuber_definitions.Resource):
 
 class RoleBindingList(_kuber_definitions.Collection):
     """
-    RoleBindingList is a collection of RoleBindings
+    RoleBindingList is a collection of RoleBindings Deprecated
+    in v1.17 in favor of rbac.authorization.k8s.io/v1
+    RoleBindingList, and will no longer be served in v1.22.
     """
 
     def __init__(
@@ -1383,7 +1397,9 @@ class RoleBindingList(_kuber_definitions.Collection):
 
 class RoleList(_kuber_definitions.Collection):
     """
-    RoleList is a collection of Roles
+    RoleList is a collection of Roles Deprecated in v1.17 in
+    favor of rbac.authorization.k8s.io/v1 RoleList, and will no
+    longer be served in v1.22.
     """
 
     def __init__(
