@@ -5,9 +5,9 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_15.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_15.meta_v1 import MicroTime  # noqa: F401
-from kuber.v1_15.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_20.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_20.meta_v1 import MicroTime  # noqa: F401
+from kuber.v1_20.meta_v1 import ObjectMeta  # noqa: F401
 
 
 class Lease(_kuber_definitions.Resource):
@@ -37,8 +37,8 @@ class Lease(_kuber_definitions.Resource):
     def metadata(self) -> "ObjectMeta":
         """
         More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return typing.cast(
             "ObjectMeta",
@@ -49,8 +49,8 @@ class Lease(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
         """
         More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -63,8 +63,8 @@ class Lease(_kuber_definitions.Resource):
     def spec(self) -> "LeaseSpec":
         """
         Specification of the Lease. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return typing.cast(
             "LeaseSpec",
@@ -75,8 +75,8 @@ class Lease(_kuber_definitions.Resource):
     def spec(self, value: typing.Union["LeaseSpec", dict]):
         """
         Specification of the Lease. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -257,8 +257,8 @@ class LeaseList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -269,8 +269,8 @@ class LeaseList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
