@@ -5,9 +5,9 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_19.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_19.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_19.core_v1 import Toleration  # noqa: F401
+from kuber.v1_20.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_20.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_20.core_v1 import Toleration  # noqa: F401
 
 
 class Overhead(_kuber_definitions.Definition):
@@ -429,8 +429,8 @@ class RuntimeClassSpec(_kuber_definitions.Definition):
         are equivalent on every node. For example, a handler called
         "runc" might specify that the runc OCI runtime (using native
         Linux containers) will be used to run the containers in a
-        pod. The RuntimeHandler must conform to the DNS Label (RFC
-        1123) requirements and is immutable.
+        pod. The RuntimeHandler must be lowercase, conform to the
+        DNS Label (RFC 1123) requirements, and is immutable.
         """
         return typing.cast(
             str,
@@ -448,8 +448,8 @@ class RuntimeClassSpec(_kuber_definitions.Definition):
         are equivalent on every node. For example, a handler called
         "runc" might specify that the runc OCI runtime (using native
         Linux containers) will be used to run the containers in a
-        pod. The RuntimeHandler must conform to the DNS Label (RFC
-        1123) requirements and is immutable.
+        pod. The RuntimeHandler must be lowercase, conform to the
+        DNS Label (RFC 1123) requirements, and is immutable.
         """
         self._properties["runtimeHandler"] = value
 
