@@ -5,9 +5,9 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_16.meta_v1 import LabelSelector  # noqa: F401
-from kuber.v1_16.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_16.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_20.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_20.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_20.meta_v1 import ObjectMeta  # noqa: F401
 
 
 class AggregationRule(_kuber_definitions.Definition):
@@ -77,7 +77,9 @@ class ClusterRole(_kuber_definitions.Resource):
     """
     ClusterRole is a cluster level, logical grouping of
     PolicyRules that can be referenced as a unit by a
-    RoleBinding or ClusterRoleBinding.
+    RoleBinding or ClusterRoleBinding. Deprecated in v1.17 in
+    favor of rbac.authorization.k8s.io/v1 ClusterRole, and will
+    no longer be served in v1.22.
     """
 
     def __init__(
@@ -302,7 +304,9 @@ class ClusterRoleBinding(_kuber_definitions.Resource):
     """
     ClusterRoleBinding references a ClusterRole, but not contain
     it.  It can reference a ClusterRole in the global namespace,
-    and adds who information via Subject.
+    and adds who information via Subject. Deprecated in v1.17 in
+    favor of rbac.authorization.k8s.io/v1 ClusterRoleBinding,
+    and will no longer be served in v1.22.
     """
 
     def __init__(
@@ -530,7 +534,9 @@ class ClusterRoleBinding(_kuber_definitions.Resource):
 class ClusterRoleBindingList(_kuber_definitions.Collection):
     """
     ClusterRoleBindingList is a collection of
-    ClusterRoleBindings
+    ClusterRoleBindings. Deprecated in v1.17 in favor of
+    rbac.authorization.k8s.io/v1 ClusterRoleBindings, and will
+    no longer be served in v1.22.
     """
 
     def __init__(
@@ -624,7 +630,9 @@ class ClusterRoleBindingList(_kuber_definitions.Collection):
 
 class ClusterRoleList(_kuber_definitions.Collection):
     """
-    ClusterRoleList is a collection of ClusterRoles
+    ClusterRoleList is a collection of ClusterRoles. Deprecated
+    in v1.17 in favor of rbac.authorization.k8s.io/v1
+    ClusterRoles, and will no longer be served in v1.22.
     """
 
     def __init__(
@@ -777,14 +785,11 @@ class PolicyRule(_kuber_definitions.Definition):
         """
         NonResourceURLs is a set of partial urls that a user should
         have access to.  *s are allowed, but only as the full, final
-        step in the path This name is intentionally different than
-        the internal type so that the DefaultConvert works nicely
-        and because the ordering may be different. Since non-
-        resource URLs are not namespaced, this field is only
-        applicable for ClusterRoles referenced from a
-        ClusterRoleBinding. Rules can either apply to API resources
-        (such as "pods" or "secrets") or non-resource URL paths
-        (such as "/api"),  but not both.
+        step in the path Since non-resource URLs are not namespaced,
+        this field is only applicable for ClusterRoles referenced
+        from a ClusterRoleBinding. Rules can either apply to API
+        resources (such as "pods" or "secrets") or non-resource URL
+        paths (such as "/api"),  but not both.
         """
         return typing.cast(
             typing.List[str],
@@ -796,14 +801,11 @@ class PolicyRule(_kuber_definitions.Definition):
         """
         NonResourceURLs is a set of partial urls that a user should
         have access to.  *s are allowed, but only as the full, final
-        step in the path This name is intentionally different than
-        the internal type so that the DefaultConvert works nicely
-        and because the ordering may be different. Since non-
-        resource URLs are not namespaced, this field is only
-        applicable for ClusterRoles referenced from a
-        ClusterRoleBinding. Rules can either apply to API resources
-        (such as "pods" or "secrets") or non-resource URL paths
-        (such as "/api"),  but not both.
+        step in the path Since non-resource URLs are not namespaced,
+        this field is only applicable for ClusterRoles referenced
+        from a ClusterRoleBinding. Rules can either apply to API
+        resources (such as "pods" or "secrets") or non-resource URL
+        paths (such as "/api"),  but not both.
         """
         self._properties["nonResourceURLs"] = value
 
@@ -878,7 +880,9 @@ class PolicyRule(_kuber_definitions.Definition):
 class Role(_kuber_definitions.Resource):
     """
     Role is a namespaced, logical grouping of PolicyRules that
-    can be referenced as a unit by a RoleBinding.
+    can be referenced as a unit by a RoleBinding. Deprecated in
+    v1.17 in favor of rbac.authorization.k8s.io/v1 Role, and
+    will no longer be served in v1.22.
     """
 
     def __init__(
@@ -1073,7 +1077,9 @@ class RoleBinding(_kuber_definitions.Resource):
     in the global namespace. It adds who information via
     Subjects and namespace information by which namespace it
     exists in.  RoleBindings in a given namespace only have
-    effect in that namespace.
+    effect in that namespace. Deprecated in v1.17 in favor of
+    rbac.authorization.k8s.io/v1 RoleBinding, and will no longer
+    be served in v1.22.
     """
 
     def __init__(
@@ -1294,7 +1300,9 @@ class RoleBinding(_kuber_definitions.Resource):
 
 class RoleBindingList(_kuber_definitions.Collection):
     """
-    RoleBindingList is a collection of RoleBindings
+    RoleBindingList is a collection of RoleBindings Deprecated
+    in v1.17 in favor of rbac.authorization.k8s.io/v1
+    RoleBindingList, and will no longer be served in v1.22.
     """
 
     def __init__(
@@ -1385,7 +1393,9 @@ class RoleBindingList(_kuber_definitions.Collection):
 
 class RoleList(_kuber_definitions.Collection):
     """
-    RoleList is a collection of Roles
+    RoleList is a collection of Roles. Deprecated in v1.17 in
+    favor of rbac.authorization.k8s.io/v1 RoleList, and will no
+    longer be served in v1.22.
     """
 
     def __init__(
