@@ -5,9 +5,9 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_17.meta_v1 import LabelSelector  # noqa: F401
-from kuber.v1_17.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_17.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_21.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_21.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_21.meta_v1 import ObjectMeta  # noqa: F401
 
 
 class MutatingWebhook(_kuber_definitions.Definition):
@@ -492,7 +492,7 @@ class MutatingWebhook(_kuber_definitions.Definition):
         Acceptable values are: Unknown, None, Some, NoneOnDryRun
         Webhooks with side effects MUST implement a reconciliation
         system, since a request may be rejected by a future step in
-        the admission change and the side effects therefore need to
+        the admission chain and the side effects therefore need to
         be undone. Requests with the dryRun attribute will be auto-
         rejected if they match a webhook with sideEffects == Unknown
         or Some. Defaults to Unknown.
@@ -509,7 +509,7 @@ class MutatingWebhook(_kuber_definitions.Definition):
         Acceptable values are: Unknown, None, Some, NoneOnDryRun
         Webhooks with side effects MUST implement a reconciliation
         system, since a request may be rejected by a future step in
-        the admission change and the side effects therefore need to
+        the admission chain and the side effects therefore need to
         be undone. Requests with the dryRun attribute will be auto-
         rejected if they match a webhook with sideEffects == Unknown
         or Some. Defaults to Unknown.
@@ -942,8 +942,10 @@ class RuleWithOperations(_kuber_definitions.Definition):
     def operations(self) -> typing.List[str]:
         """
         Operations is the operations the admission hook cares about
-        - CREATE, UPDATE, or * for all operations. If '*' is
-        present, the length of the slice must be one. Required.
+        - CREATE, UPDATE, DELETE, CONNECT or * for all of those
+        operations and any future admission operations that are
+        added. If '*' is present, the length of the slice must be
+        one. Required.
         """
         return typing.cast(
             typing.List[str],
@@ -954,8 +956,10 @@ class RuleWithOperations(_kuber_definitions.Definition):
     def operations(self, value: typing.List[str]):
         """
         Operations is the operations the admission hook cares about
-        - CREATE, UPDATE, or * for all operations. If '*' is
-        present, the length of the slice must be one. Required.
+        - CREATE, UPDATE, DELETE, CONNECT or * for all of those
+        operations and any future admission operations that are
+        added. If '*' is present, the length of the slice must be
+        one. Required.
         """
         self._properties["operations"] = value
 
@@ -1564,7 +1568,7 @@ class ValidatingWebhook(_kuber_definitions.Definition):
         Acceptable values are: Unknown, None, Some, NoneOnDryRun
         Webhooks with side effects MUST implement a reconciliation
         system, since a request may be rejected by a future step in
-        the admission change and the side effects therefore need to
+        the admission chain and the side effects therefore need to
         be undone. Requests with the dryRun attribute will be auto-
         rejected if they match a webhook with sideEffects == Unknown
         or Some. Defaults to Unknown.
@@ -1581,7 +1585,7 @@ class ValidatingWebhook(_kuber_definitions.Definition):
         Acceptable values are: Unknown, None, Some, NoneOnDryRun
         Webhooks with side effects MUST implement a reconciliation
         system, since a request may be rejected by a future step in
-        the admission change and the side effects therefore need to
+        the admission chain and the side effects therefore need to
         be undone. Requests with the dryRun attribute will be auto-
         rejected if they match a webhook with sideEffects == Unknown
         or Some. Defaults to Unknown.
