@@ -5,9 +5,9 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_16.meta_v1 import LabelSelector  # noqa: F401
-from kuber.v1_16.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_16.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_22.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_22.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_22.meta_v1 import ObjectMeta  # noqa: F401
 
 
 class AggregationRule(_kuber_definitions.Definition):
@@ -824,8 +824,8 @@ class PolicyRule(_kuber_definitions.Definition):
     @property
     def resources(self) -> typing.List[str]:
         """
-        Resources is a list of resources this rule applies to.
-        ResourceAll represents all resources.
+        Resources is a list of resources this rule applies to. '*'
+        represents all resources.
         """
         return typing.cast(
             typing.List[str],
@@ -835,8 +835,8 @@ class PolicyRule(_kuber_definitions.Definition):
     @resources.setter
     def resources(self, value: typing.List[str]):
         """
-        Resources is a list of resources this rule applies to.
-        ResourceAll represents all resources.
+        Resources is a list of resources this rule applies to. '*'
+        represents all resources.
         """
         self._properties["resources"] = value
 
@@ -844,8 +844,8 @@ class PolicyRule(_kuber_definitions.Definition):
     def verbs(self) -> typing.List[str]:
         """
         Verbs is a list of Verbs that apply to ALL the ResourceKinds
-        and AttributeRestrictions contained in this rule.  VerbAll
-        represents all kinds.
+        and AttributeRestrictions contained in this rule. '*'
+        represents all verbs.
         """
         return typing.cast(
             typing.List[str],
@@ -856,8 +856,8 @@ class PolicyRule(_kuber_definitions.Definition):
     def verbs(self, value: typing.List[str]):
         """
         Verbs is a list of Verbs that apply to ALL the ResourceKinds
-        and AttributeRestrictions contained in this rule.  VerbAll
-        represents all kinds.
+        and AttributeRestrictions contained in this rule. '*'
+        represents all verbs.
         """
         self._properties["verbs"] = value
 
